#!/bin/bash


#Set PG variables
export PGDATA=/home/amit.kapila/workspace/master/data
export PGPORT=5432
export LD_LIBRARY_PATH=/home/amit.kapila/workspace/master/installation/lib:$LD_LIBRARY_PATH

# config_values
no_of_readings=3
shared_bufs=8GB
run_bin="parallel_append"

# test specifications
ntests=1
testname[ntests]="costly qual and 1% of rows will be selected"
teststatement[ntests]="Explain analyze select count(*) from pgbench_accounts where 
aid < calc_factorial(100000,10);"
let "ntests++"

testname[ntests]="costly qual and 10% of rows will be selected"
teststatement[ntests]="Explain analyze select count(*) from pgbench_accounts where 
aid < calc_factorial(1000000,10);"
let "ntests++"

testname[ntests]="costly qual and 25% of rows will be selected"
teststatement[ntests]="Explain analyze select count(*) from pgbench_accounts where 
aid < calc_factorial(2500000,10);"
let "ntests++"


create_calc_factorial="create or replace function calc_factorial(a integer, fact_val integer) returns integer
as \$\$
begin
	perform (fact_val)!;
        return a;
end;
\$\$ language plpgsql PARALLEL SAFE"

drop_calc_factorial="drop function calc_factorial(integer,integer)"

echo "============== $run_bin =============" >> test_results.txt
cp postgres_${run_bin} postgres

#Start the server
./postgres -c shared_buffers=$shared_bufs &

sleep 5 

./psql -d postgres -c "$create_calc_factorial"

for ((count_stmt = 1; count_stmt < $ntests; count_stmt++))
do
	for parallel_degree in 0 2 4 8 16 32 64 
	do       
        #Start taking reading
		for ((readcnt = 1 ; readcnt <= $no_of_readings ; readcnt++))
		do
			echo "================================================"  >> test_results.txt
			echo $testname[$count_stmt] parallel_seqscan_degree - ${parallel_degree} Reading - ${readcnt} >> test_results.txt

			# Run Statement
			./psql -d postgres -c "set max_parallel_degree=$parallel_degree;set parallel_tuple_cost=0.001;${teststatement[$count_stmt]}" >> test_results.txt
		done;
	done;
done;


./psql -d postgres -c "$drop_calc_factorial"
./psql -d postgres -c "checkpoint" >> test_results.txt
./pg_ctl stop
sleep 1


mv test_results.txt test_results_${run_bin}.txt
